@@ -12,10 +12,31 @@
 #' @examples
 #' full_seq(c(1, 2, 4, 5, 10), 1)
 full_seq <- function(x, period, tol = 1e-6) {
-  if (any(x %% period > tol)) {
+  UseMethod("full_seq")
+}
+
+#' @export
+full_seq.numeric <- function(x, period, tol = 1e-6) {
+  rng <- range(x, na.rm = TRUE)
+  if (any((x - rng[1]) %% period > tol)) {
     stop("`x` is not a regular sequence.", call. = FALSE)
   }
 
-  rng <- range(x, na.rm = TRUE)
   seq(rng[1], rng[2], by = period)
 }
+
+#' @export
+full_seq.Date <- function(x, period, tol = 1e-6) {
+  restore(full_seq(as.numeric(x), period, tol), x)
+}
+
+#' @export
+full_seq.POSIXct <- function(x, period, tol = 1e-6) {
+  restore(full_seq(as.numeric(x), period, tol), x)
+}
+
+
+restore <- function(old, new) {
+  mostattributes(new) <- attributes(old)
+  new
+}
